api.system.components.code.v1 package — Argus-Toolbelt 1.0 documentation

# api.system.components.code.v1 package

## Submodules

## api.system.components.code.v1.artifact module

Autogenerated API

`api.system.components.code.v1.artifact.` `create`(groupID: str = None, artifactID: str = None, version: str = None, data: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add new code artifact (INTERNAL) (INTERNAL)

  Return type: | `dict`
  Parameters: | groupID (str) – [a-zA-Z0-9_-.]* artifactID (str) – [a-zA-Z0-9_-.]* version (str) – [a-zA-Z0-9_-.]* data (str) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 355, “limit”: 854, “responseCode”: 200, “count”: 779, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Five name head end clear born significant.”, “messageTemplate”: “Head early break capital police.”, “field”: “Very picture cover ahead produce use player.”, “parameter”: {}, “timestamp”: 1191403886}], “currentPage”: 619, “size”: 758}

`api.system.components.code.v1.artifact.` `create_from_octet_stream`(groupID: str, artifactID: str, version: str, body: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add new code artifact (INTERNAL)

  Return type: | `dict`
  Parameters: | groupID (str) – Group ID artifactID (str) – Artifact ID version (str) – Version body (`str`) – Artifact data
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 293, “limit”: 572, “responseCode”: 200, “count”: 196, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Civil per write current action avoid.”, “messageTemplate”: “Media onto realize especially radio success.”, “field”: “Though economy light option.”, “parameter”: {}, “timestamp”: 1361607938}], “currentPage”: 96, “size”: 834}

`api.system.components.code.v1.artifact.` `delete_unused`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Mark unused artifacts as deleted (INTERNAL)

  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 551, “limit”: 46, “responseCode”: 200, “count”: 874, “data”: [{“id”: “Nor car government as central exist figure.”, “groupID”: “Moment create her live trial.”, “artifactID”: “Success common next country scientist.”, “version”: “Strong accept future Democrat.”, “flags”: 351, “status”: “DELETED”, “createdTimestamp”: 988482543, “lastUpdatedTimestamp”: 57925875, “createdByUser”: {“id”: 903, “customerID”: 297, “userName”: “marshallrichard”, “name”: “Kyle Weaver”}, “lastUpdatedByUser”: {“id”: 395, “customerID”: 679, “userName”: “burnettdavid”, “name”: “Michelle Smith”}, “length”: 213, “data”: “Reveal though factor deal.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Chair the must alone subject newspaper thought serve.”, “messageTemplate”: “Series building economy against.”, “field”: “All charge police.”, “parameter”: {}, “timestamp”: 587880147}], “currentPage”: 231, “size”: 640}

`api.system.components.code.v1.artifact.` `download_by_g_a_v`(groupID: str, artifactID: str, version: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Download artifact by groupID, artifactID and version (GAV) (INTERNAL)

  Return type: | `dict`
  Parameters: | groupID (str) – GroupID of artifact to fetch artifactID (str) – ArtifactID of artifact to fetch version (str) – Version of artifact to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 319, “limit”: 935, “responseCode”: 200, “count”: 178, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Record training tonight me bank system figure.”, “messageTemplate”: “Money executive professor.”, “field”: “Manager join collection big mention attack long management.”, “parameter”: {}, “timestamp”: 506467772}], “currentPage”: 149, “size”: 963}

`api.system.components.code.v1.artifact.` `download_by_id`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Download artifact by ID (INTERNAL)

  Return type: | `dict`
  Parameters: | id (str) – ID of artifact to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {}

`api.system.components.code.v1.artifact.` `get_by_g_a_v`(groupID: str, artifactID: str, version: str, includeData: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch code artifact by groupID, artifactID and version (GAV) (INTERNAL)

  Return type: | `dict`
  Parameters: | groupID (str) – GroupID of artifact to fetch artifactID (str) – ArtifactID of artifact to fetch version (str) – Version of artifact to fetch includeData (bool) – If true, include encoded artifact binary data
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 114, “limit”: 566, “responseCode”: 200, “count”: 176, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “The health enough use upon table since.”, “messageTemplate”: “Rule run minute already each office because.”, “field”: “Pull back of.”, “parameter”: {}, “timestamp”: 826009536}], “currentPage”: 451, “size”: 157}

`api.system.components.code.v1.artifact.` `get_by_id`(id: str, includeData: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch code artifact by hash ID (INTERNAL)

  Return type: | `dict`
  Parameters: | id (str) – ID of artifact to fetch includeData (bool) – If true, include encoded artifact binary data
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 993, “limit”: 144, “responseCode”: 200, “count”: 610, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Agent our cold southern little.”, “messageTemplate”: “Difficult fact provide season though hand.”, “field”: “Necessary art run wide high exactly interest west.”, “parameter”: {}, “timestamp”: 294027646}], “currentPage”: 101, “size”: 443}

`api.system.components.code.v1.artifact.` `list`(search: str = None, orderDesc: bool = None, limit: int = 25, offset: int = 0, orderBy: str = 'groupID', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List code artifacts (INTERNAL)

  Return type: | `dict`
  Parameters: | search (str) – Limit result to artifacts matching this search string orderDesc (bool) – Sort results descending limit (int) – Limit result offset (int) – Offset result orderBy (str) – Order result
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 560, “limit”: 787, “responseCode”: 200, “count”: 789, “data”: [{“id”: “Society occur they impact.”, “groupID”: “Loss learn size fall measure this how.”, “artifactID”: “Yeah interview day teach check history dog.”, “version”: “Central never adult under argue theory degree.”, “flags”: 717, “status”: “DELETED”, “createdTimestamp”: 1116810724, “lastUpdatedTimestamp”: 1095938355, “createdByUser”: {“id”: 787, “customerID”: 725, “userName”: “pageglenn”, “name”: “Matthew Peterson”}, “lastUpdatedByUser”: {“id”: 502, “customerID”: 294, “userName”: “tammy77”, “name”: “Jason Miller”}, “length”: 603, “data”: “Police protect third red.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Look use see not treat.”, “messageTemplate”: “Evidence if dinner win indeed like receive.”, “field”: “Black choice industry sort.”, “parameter”: {}, “timestamp”: 127938807}], “currentPage”: 252, “size”: 162}

`api.system.components.code.v1.artifact.` `list_unused`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List unused artifact (INTERNAL)

  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 33, “limit”: 194, “responseCode”: 200, “count”: 448, “data”: [{“id”: “First hand ago film word head family Congress.”, “groupID”: “Move well group ago Democrat.”, “artifactID”: “Price than stage first include admit maybe.”, “version”: “Pull society teach push.”, “flags”: 315, “status”: “ACTIVE”, “createdTimestamp”: 692361631, “lastUpdatedTimestamp”: 171887021, “createdByUser”: {“id”: 81, “customerID”: 98, “userName”: “michael29”, “name”: “Karla White”}, “lastUpdatedByUser”: {“id”: 936, “customerID”: 540, “userName”: “cookvincent”, “name”: “Haley Doyle”}, “length”: 590, “data”: “Herself blue away blue between.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Something trade house score dark another official.”, “messageTemplate”: “Keep stuff safe safe.”, “field”: “Newspaper rule campaign they production despite per.”, “parameter”: {}, “timestamp”: 1333704878}], “currentPage”: 299, “size”: 350}

`api.system.components.code.v1.artifact.` `search`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: <function list at 0x1114e37b8> = None, searchString: str = None, id: <function list at 0x1114e37b8> = None, groupID: <function list at 0x1114e37b8> = None, artifactID: <function list at 0x1114e37b8> = None, version: <function list at 0x1114e37b8> = None, status: <function list at 0x1114e37b8> = None, gav: <function list at 0x1114e37b8> = None, startTimestamp: int = None, endTimestamp: int = None, sortBy: <function list at 0x1114e37b8> = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeData: bool = 'False', includeCreatedTimestamp: bool = 'False', includeLastUpdatedTimestamp: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search code artifacts (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – searchString (str) – id (list) – groupID (list) – artifactID (list) – version (list) – status (list) – gav (list) – startTimestamp (int) – endTimestamp (int) – sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeData (bool) – includeCreatedTimestamp (bool) – includeLastUpdatedTimestamp (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 27, “limit”: 671, “responseCode”: 200, “count”: 470, “data”: [{“id”: “Party down table protect.”, “groupID”: “Amount enjoy matter establish south.”, “artifactID”: “Parent without food sell control probably Congress fight.”, “version”: “Trial with stock answer message assume.”, “flags”: 688, “status”: “UNUSED”, “createdTimestamp”: 156363789, “lastUpdatedTimestamp”: 705538842, “createdByUser”: {“id”: 485, “customerID”: 26, “userName”: “tamara05”, “name”: “Dominic Walton”}, “lastUpdatedByUser”: {“id”: 667, “customerID”: 248, “userName”: “bbush”, “name”: “Daniel Jordan”}, “length”: 173, “data”: “Ball way understand leg stage middle.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Cold start process apply ago although.”, “messageTemplate”: “Himself top modern then rock modern space.”, “field”: “Walk world else rock mind Republican.”, “parameter”: {}, “timestamp”: 1268836140}], “currentPage”: 195, “size”: 775}

## api.system.components.code.v1.profile module

Autogenerated API

`api.system.components.code.v1.profile.` `attach`(profileID: int, artifactID: <function list at 0x11119e7b8>, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Attach artifact to profile (INTERNAL)

  Return type: | `dict`
  Parameters: | profileID (int) – ID of profile to attach to artifactID (list) – Hash ID of artifacts to attach
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 351, “limit”: 324, “responseCode”: 200, “count”: 883, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Establish new lot employee serious life agent.”, “messageTemplate”: “Pretty agreement attorney sell organization member.”, “field”: “Other according well science listen suffer skin.”, “parameter”: {}, “timestamp”: 321484118}], “currentPage”: 750, “size”: 426}

`api.system.components.code.v1.profile.` `attach_by_name`(profileName: str, groupID: str, artifactID: str, version: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Attach artifact to profile by profile name and artifact GAV (INTERNAL)

  Return type: | `dict`
  Parameters: | profileName (str) – Name of profile to attach to groupID (str) – GroupID of artifact to attach artifactID (str) – ArtifactID of artifact to attach version (str) – Version of artifact to attach
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 633, “limit”: 874, “responseCode”: 200, “count”: 192, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Even name within during.”, “messageTemplate”: “Exactly want cultural more face reduce boy.”, “field”: “Should enter again recognize against.”, “parameter”: {}, “timestamp”: 1086345610}], “currentPage”: 811, “size”: 923}

`api.system.components.code.v1.profile.` `attach_detach`(profileID: int, artifactsToAttach: <function list at 0x11119e7b8> = None, artifactsToDetach: <function list at 0x11119e7b8> = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Attach and detach artifact to given profile (INTERNAL)

  Return type: | `dict`
  Parameters: | profileID (int) – ID of profile to detach from artifactsToAttach (list) – artifactsToDetach (list) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 291, “limit”: 262, “responseCode”: 200, “count”: 673, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “End or mission bring read exactly wide join.”, “messageTemplate”: “Happy clear manage.”, “field”: “Organization cause five student huge share positive.”, “parameter”: {}, “timestamp”: 1253654022}], “currentPage”: 401, “size”: 990}

`api.system.components.code.v1.profile.` `create`(name: str = None, artifactsToAttach: <function list at 0x11119e7b8> = None, finalize: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add new code profile (INTERNAL)

  Return type: | `dict`
  Parameters: | name (str) – [a-zA-Z0-9_-.]* artifactsToAttach (list) – finalize (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 998, “limit”: 362, “responseCode”: 200, “count”: 835, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Partner system family culture.”, “messageTemplate”: “Accept level opportunity own community culture.”, “field”: “Meet even dog west factor.”, “parameter”: {}, “timestamp”: 799169130}], “currentPage”: 907, “size”: 180}

`api.system.components.code.v1.profile.` `delete`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Mark code profile as deleted (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of profile to delete
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 901, “limit”: 813, “responseCode”: 200, “count”: 458, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Medical sign save for.”, “messageTemplate”: “Performance human protect dinner.”, “field”: “Probably clear those commercial analysis according.”, “parameter”: {}, “timestamp”: 369434938}], “currentPage”: 716, “size”: 433}

`api.system.components.code.v1.profile.` `detach`(profileID: int, artifactID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Detach artifact to profile (INTERNAL)

  Return type: | `dict`
  Parameters: | profileID (int) – ID of profile to detach from artifactID (str) – Hash ID of artifact to detach
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 696, “limit”: 469, “responseCode”: 200, “count”: 179, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Us human risk special seem.”, “messageTemplate”: “Even near rise blue.”, “field”: “Glass rich open sport citizen miss.”, “parameter”: {}, “timestamp”: 600496866}], “currentPage”: 814, “size”: 122}

`api.system.components.code.v1.profile.` `detach_by_artifact_by_g_a`(profileName: str, groupID: str, artifactID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Detach artifact from profile by profile name and artifact GAV (INTERNAL) Will detach all artifacts with given group ID artifact ID, regardless of version

  Return type: | `dict`

`api.system.components.code.v1.profile.` `detach_by_name`(profileName: str, groupID: str, artifactID: str, version: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Detach artifact from profile by profile name and artifact GAV (INTERNAL)

  Return type: | `dict`
  Parameters: | profileName (str) – Name of profile to detach from groupID (str) – GroupID of artifact to detach artifactID (str) – ArtifactID of artifact to detach version (str) – Version of artifact to detach
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 798, “limit”: 899, “responseCode”: 200, “count”: 251, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Trouble mind this direction.”, “messageTemplate”: “Say prevent time voice hit story.”, “field”: “Republican skill while too.”, “parameter”: {}, “timestamp”: 971012118}], “currentPage”: 643, “size”: 212}

`api.system.components.code.v1.profile.` `duplicate`(id: int, name: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Duplicate existing code profile (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of profile to duplicate name (str) – Name of new profile
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 348, “limit”: 205, “responseCode”: 200, “count”: 979, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Move national develop live.”, “messageTemplate”: “Thing kid both performance eat would.”, “field”: “Top pretty particular difficult responsibility hold.”, “parameter”: {}, “timestamp”: 789341290}], “currentPage”: 295, “size”: 657}

`api.system.components.code.v1.profile.` `get_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get code profile by ID (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of profile to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 600, “limit”: 726, “responseCode”: 200, “count”: 487, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Over visit leader better.”, “messageTemplate”: “Kid on far room condition add either.”, “field”: “Sense pretty learn indicate.”, “parameter”: {}, “timestamp”: 435201527}], “currentPage”: 591, “size”: 799}

`api.system.components.code.v1.profile.` `get_by_name`(name: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get code profile by name (INTERNAL)

  Return type: | `dict`
  Parameters: | name (str) – Name of profile to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 717, “limit”: 713, “responseCode”: 200, “count”: 846, “data”: [{“id”: 614, “name”: “Kelli Lutz”, “flags”: 541, “created”: 485, “createdByUser”: {“id”: 292, “customerID”: 822, “userName”: “jonathan10”, “name”: “Terri Fowler”}, “lastUpdatedTimestamp”: 688596507, “lastUpdatedByUser”: {“id”: 847, “customerID”: 749, “userName”: “ygarrett”, “name”: “Tracie Terrell”}, “artifacts”: [{“id”: “Enter rich successful very town they.”, “groupID”: “Back someone product heavy left allow audience.”, “artifactID”: “Where art reason talk wide group nice crime.”, “version”: “Explain establish box laugh rule hair.”, “flags”: 919, “status”: “UNUSED”, “createdTimestamp”: 725965946, “lastUpdatedTimestamp”: 1134582673, “length”: 801, “data”: “Score trip rise then thank debate.”}], “deleted”: true, “finalized”: false}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Large fact possible person bag.”, “messageTemplate”: “Thought camera century program along although movement.”, “field”: “Word central ten whether off.”, “parameter”: {}, “timestamp”: 644469347}], “currentPage”: 121, “size”: 317}

`api.system.components.code.v1.profile.` `list`(orderDesc: bool = None, limit: int = 25, offset: int = 0, orderBy: str = 'name', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List code profiles (INTERNAL)

  Return type: | `dict`
  Parameters: | orderDesc (bool) – Sort results descending limit (int) – Limit results offset (int) – Offset results orderBy (str) – Sort results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 434, “limit”: 37, “responseCode”: 200, “count”: 33, “data”: [{“id”: 517, “name”: “Bradley Lee”, “flags”: 975, “created”: 411, “createdByUser”: {“id”: 903, “customerID”: 562, “userName”: “kathryn65”, “name”: “Juan Clark”}, “lastUpdatedTimestamp”: 1099669702, “lastUpdatedByUser”: {“id”: 351, “customerID”: 951, “userName”: “shunt”, “name”: “Amanda Pennington”}, “artifacts”: [{“id”: “Growth visit approach whatever.”, “groupID”: “Peace wear use fish.”, “artifactID”: “Spend similar serve tell mother.”, “version”: “Particularly total than reduce.”, “flags”: 308, “status”: “DELETED”, “createdTimestamp”: 1408923449, “lastUpdatedTimestamp”: 284886820, “length”: 996, “data”: “Full purpose remain rich.”}], “deleted”: true, “finalized”: false}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Serve develop yes yard issue.”, “messageTemplate”: “Dog degree share want.”, “field”: “Little whole always why point local.”, “parameter”: {}, “timestamp”: 1397759996}], “currentPage”: 391, “size”: 247}

`api.system.components.code.v1.profile.` `search`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: <function list at 0x11119e7b8> = None, searchString: str = None, usingArtifact: <function list at 0x11119e7b8> = None, startTimestamp: int = None, endTimestamp: int = None, sortBy: <function list at 0x11119e7b8> = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeArtifacts: bool = 'False', includeCreatedTimestamp: bool = 'False', includeLastUpdatedTimestamp: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search code profiles (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – searchString (str) – usingArtifact (list) – startTimestamp (int) – endTimestamp (int) – sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeArtifacts (bool) – includeCreatedTimestamp (bool) – includeLastUpdatedTimestamp (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 518, “limit”: 903, “responseCode”: 200, “count”: 264, “data”: [{“id”: 272, “name”: “Erica Mercer”, “flags”: 576, “created”: 42, “createdByUser”: {“id”: 821, “customerID”: 514, “userName”: “kbrown”, “name”: “Virginia Martin”}, “lastUpdatedTimestamp”: 926834382, “lastUpdatedByUser”: {“id”: 824, “customerID”: 890, “userName”: “edwardwilson”, “name”: “Jason Gutierrez”}, “artifacts”: [{“id”: “Through remember teach always clearly day.”, “groupID”: “Though college others benefit.”, “artifactID”: “Weight protect oil clearly candidate.”, “version”: “Theory laugh individual table.”, “flags”: 144, “status”: “ACTIVE”, “createdTimestamp”: 279321359, “lastUpdatedTimestamp”: 180340114, “length”: 744, “data”: “Last friend ready environment item.”}], “deleted”: true, “finalized”: true}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Become play card nice.”, “messageTemplate”: “Our employee natural green score free who.”, “field”: “Top cause pay just value.”, “parameter”: {}, “timestamp”: 291510201}], “currentPage”: 19, “size”: 724}

`api.system.components.code.v1.profile.` `update`(id: int, name: str = None, finalized: bool = 'False', useForUnknown: bool = 'False', setAsDefault: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update code profile (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of profile to update name (str) – [a-zA-Z0-9_-.]* finalized (bool) – useForUnknown (bool) – setAsDefault (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 492, “limit”: 518, “responseCode”: 200, “count”: 659, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Knowledge can member evidence dark small government.”, “messageTemplate”: “Ever staff protect pick sister.”, “field”: “Until party fire notice.”, “parameter”: {}, “timestamp”: 773109939}], “currentPage”: 145, “size”: 529}

## api.system.components.code.v1.vacuum module

Autogenerated API

`api.system.components.code.v1.vacuum.` `vacuum`(historyLimit: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Vacuum code profiles and artifacts (INTERNAL) Will delete all objects marked as deleted, which are older than historyLimit. Returns the number of deleted objects.

  Return type: | `dict`

## Module contents